@@ -2,19 +2,20 @@ package Text::Template::Simple;
 use strict;
 use warnings;
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 use File::Spec;
-use Text::Template::Simple::Constants qw(:all);
-use Text::Template::Simple::Dummy;
+
+use Text::Template::Simple::Cache;
+use Text::Template::Simple::Cache::ID;
+use Text::Template::Simple::Caller;
 use Text::Template::Simple::Compiler;
 use Text::Template::Simple::Compiler::Safe;
-use Text::Template::Simple::Caller;
-use Text::Template::Simple::Tokenizer;
-use Text::Template::Simple::Util qw(:all);
-use Text::Template::Simple::Cache::ID;
-use Text::Template::Simple::Cache;
+use Text::Template::Simple::Constants qw(:all);
+use Text::Template::Simple::Dummy;
 use Text::Template::Simple::IO;
+use Text::Template::Simple::Tokenizer;
+use Text::Template::Simple::Util      qw(:all);
 
 use base qw(
    Text::Template::Simple::Base::Compiler
@@ -23,29 +24,29 @@ use base qw(
    Text::Template::Simple::Base::Parser
 );
 
-my %CONNECTOR = ( # Default classes list
-   'Cache'     => 'Text::Template::Simple::Cache',
-   'Cache::ID' => 'Text::Template::Simple::Cache::ID',
-   'IO'        => 'Text::Template::Simple::IO',
-   'Tokenizer' => 'Text::Template::Simple::Tokenizer',
+my %CONNECTOR = qw(
+   Cache       Text::Template::Simple::Cache
+   Cache::ID   Text::Template::Simple::Cache::ID
+   IO          Text::Template::Simple::IO
+   Tokenizer   Text::Template::Simple::Tokenizer
 );
 
 my %DEFAULT = ( # default object attributes
    delimiters       => [ DELIMS ],   # default delimiters
-   cache            =>  0,           # use cache or not
+   cache            => 0,            # use cache or not
    cache_dir        => EMPTY_STRING, # will use hdd intead of memory for caching...
-   strict           =>  1,           # set to false for toleration to un-declared vars
-   safe             =>  0,           # use safe compartment?
-   header           =>  0,           # template header. i.e. global codes.
+   strict           => 1,            # set to false for toleration to un-declared vars
+   safe             => 0,            # use safe compartment?
+   header           => 0,            # template header. i.e. global codes.
    add_args         => EMPTY_STRING, # will unshift template argument list. ARRAYref.
-   warn_ids         =>  0,           # warn template ids?
-   capture_warnings =>  0,           # bool
+   warn_ids         => 0,            # warn template ids?
+   capture_warnings => 0,            # bool
    iolayer          => EMPTY_STRING, # I/O layer for filehandles
    stack            => EMPTY_STRING, # dump caller stack?
    user_thandler    => undef,        # user token handler callback
-   monolith         =>  0,           # use monolithic template & cache ?
+   monolith         => 0,            # use monolithic template & cache ?
    include_paths    => [],           # list of template dirs
-   verbose_errors   =>  0,           # bool
+   verbose_errors   => 0,            # bool
    pre_chomp        => CHOMP_NONE,
    post_chomp       => CHOMP_NONE,
    taint_mode       => TAINT_CHECK_NORMAL,
@@ -74,7 +75,7 @@ sub import {
 sub tts {
    my @args = @_;
    fatal('tts.main.tts.args') if ! @args;
-   my @new  = ishref($args[0]) ? %{ shift @args } : ();
+   my @new  = ref $args[0] eq 'HASH' ? %{ shift @args } : ();
    return __PACKAGE__->new( @new )->compile( @args );
 }
 
@@ -115,7 +116,7 @@ sub io    { return shift->[IO_OBJECT]    }
 
 sub compile {
    my($self, @args) = @_;
-   my $rv    = $self->_compile( @args );
+   my $rv = $self->_compile( @args );
    # we need to reset this to prevent false positives
    # the trick is: this is set in _compile() and sub includes call _compile()
    # instead of compile(), so it will only be reset here
@@ -128,10 +129,10 @@ sub compile {
 sub _init {
    my $self = shift;
    my $d    = $self->[DELIMITERS];
-   my $bogus_args = $self->[ADD_ARGS] && ! isaref($self->[ADD_ARGS]);
+   my $bogus_args = $self->[ADD_ARGS] && ref $self->[ADD_ARGS] ne 'ARRAY';
 
    fatal('tts.main.bogus_args')   if $bogus_args;
-   fatal('tts.main.bogus_delims') if ! isaref( $d ) || $#{ $d } != 1;
+   fatal('tts.main.bogus_delims') if ref $d ne 'ARRAY' || $#{ $d } != 1;
    fatal('tts.main.dslen')        if length($d->[DELIM_START]) < 2;
    fatal('tts.main.delen')        if length($d->[DELIM_END])   < 2;
    fatal('tts.main.dsws')         if $d->[DELIM_START] =~ m{\s}xms;
@@ -143,14 +144,14 @@ sub _init {
    $self->[FAKER_HASH]     = $self->_output_buffer_var('hash');
    $self->[FAKER_SELF]     = $self->_output_buffer_var('self');
    $self->[INSIDE_INCLUDE] = RESET_FIELD;
-   $self->[NEEDS_OBJECT]   =  0; # the template needs $self ?
-   $self->[DEEP_RECURSION] =  0; # recursion detector
+   $self->[NEEDS_OBJECT]   = 0; # the template needs $self ?
+   $self->[DEEP_RECURSION] = 0; # recursion detector
 
    fatal('tts.main.init.thandler')
-      if $self->[USER_THANDLER] && ! iscref($self->[USER_THANDLER]);
+      if $self->[USER_THANDLER] && ref $self->[USER_THANDLER] ne 'CODE';
 
    fatal('tts.main.init.include')
-      if $self->[INCLUDE_PATHS] && ! isaref($self->[INCLUDE_PATHS]);
+      if $self->[INCLUDE_PATHS] && ref $self->[INCLUDE_PATHS] ne 'ARRAY';
 
    $self->[IO_OBJECT] = $self->connector('IO')->new(
                            @{ $self }[ IOLAYER, INCLUDE_PATHS, TAINT_MODE ],
@@ -251,15 +252,15 @@ Where C<hello.tts> has this content:
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple>
+released on C<5 July 2016>.
 
 This is a simple template module. There is no extra template/mini 
 language. Instead, it uses Perl as the template language. Templates
 can be cached on disk or inside the memory via the internal cache 
 manager. It is also possible to use static/dynamic includes,
 pass parameters to includes and apply filters on them.
-Also see L<Text::Template::Simple::API> for the full API definiton.
+Also see L<Text::Template::Simple::API> for the full C<API> reference.
 
 =head1 SYNTAX
 
@@ -340,7 +341,7 @@ If you put a space before the pound sign, the block will be a code block:
       my $foo = 42;
    %>
 
-If you want to include a text or html file, you can use the
+If you want to include a text or I<HTML> file, you can use the
 static include directive:
 
    <%+ my_other.html %>
@@ -360,10 +361,10 @@ is valid code:
 
 =head2 Chomping
 
-Chomping is the removal of whitespace before and after your directives. This
-can be useful if you're generating plain text (instead of HTML which'll ignore
+Chomping is the removal of white space before and after your directives. This
+can be useful if you're generating plain text (instead of HTML which will ignore
 spaces most of the time). You can either remove all space or replace multiple
-whitespace with a single space (collapse). Chomping can be enabled per
+white space with a single space (collapse). Chomping can be enabled per
 directive or globally via options to the constructor.
 See L<Text::Template::Simple::API/pre_chomp> and
 L<Text::Template::Simple::API/post_chomp> options to
@@ -439,7 +440,7 @@ Will become:
    Foo Bar
 
 Chomping is inspired by Template Toolkit (mostly the same functionality,
-although TT seems to miss collapse/no-chomp per directive option).
+although C<TT> seems to miss collapse/no-chomp per directive option).
 
 =head2 Accessing Template Names
 
@@ -475,7 +476,7 @@ do this.
 
 =head2 Template Parameters
 
-You can fetch parameters (passed to compile) in the usual perl way:
+You can fetch parameters (passed to compile) in the usual C<perl> way:
 
    <%
       my $foo = shift;
@@ -490,26 +491,20 @@ Currently supported parameters are:
 
 =over 4
 
-=item *
+=item C<PARAM>
 
-PARAM
+=item FILTER
 
-=item *
-
-FILTER
-
-=item *
-
-SHARE
+=item SHARE
 
 =back
 
    <%+ /path/to/static.tts  | FILTER: MyFilter %>
    <%* /path/to/dynamic.tts | FILTER: MyFilter | PARAM: test => 123 %>
 
-C<PARAM:> defines the parameter list to pass to the included file.
-C<FILTER:> defines the list of filters to apply to the output of the include.
-C<SHARE:> used to list the variables to share with the included template when
+C<PARAM> defines the parameter list to pass to the included file.
+C<FILTER> defines the list of filters to apply to the output of the include.
+C<SHARE> used to list the variables to share with the included template when
 the monolith option is disabled.
 
 =head3 INCLUDE FILTERS
@@ -562,7 +557,7 @@ in the below template:
    <%* dyna.inc | SHARE: $foo, $bar %>
 
 And then you can access C<$foo> and C<$bar> inside C<dyna.inc>. There is one
-drawback by shared variables: only SCALARs can be shared. You can not share
+drawback by shared variables: only C<SCALARs> can be shared. You can not share
 anything else. If you want to share an array, use an array reference instead:
 
    <%
@@ -607,15 +602,15 @@ Note that you can not use any variables in these blocks. They are static.
 
 =head2 connector
 
-=head2 io
+=head2 C<io>
 
-=head2 tts
+=head2 C<tts>
 
 See L<Text::Template::Simple::API> for the technical/gory details.
 
 =head1 EXAMPLES
 
-TODO
+   TODO
 
 =head1 ERROR HANDLING
 
@@ -631,17 +626,17 @@ Contact the author if you find any bugs.
 
 =head2 No mini language
 
-There is no mini-language. Only perl is used as the template
+There is no mini-language. Only C<perl> is used as the template
 language. So, this may or may not be I<safe> from your point
 of view. If this is a problem for you, just don't use this 
 module. There are plenty of template modules with mini-languages
-inside I<CPAN>.
+inside C<CPAN>.
 
 =head2 Speed
 
-There is an initialization cost and this'll show itself after
+There is an initialization cost and this will show itself after
 the first compilation process. The second and any following compilations
-will be much faster. Using cache can also improve speed, since this'll
+will be much faster. Using cache can also improve speed, since this will
 eliminate the parsing phase. Also, using memory cache will make
 the program run more faster under persistent environments. But the 
 overall speed really depends on your environment.
@@ -678,12 +673,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
