@@ -6,13 +6,13 @@ use warnings;
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub _init_compile_opts {
    my $self = shift;
    my $opt  = shift || {};
 
-   fatal('tts.base.compiler._compile.opt') if ! ishref( $opt );
+   fatal('tts.base.compiler._compile.opt') if ref $opt ne 'HASH';
 
    # set defaults
    $opt->{id}       ||= EMPTY_STRING; # id is AUTO
@@ -23,7 +23,7 @@ sub _init_compile_opts {
 
    # first element is the shared names. if it's not defined, then there
    # are no shared variables from top level
-   if ( isaref($opt->{_share}) && ! defined $opt->{_share}[0] ) {
+   if ( ref $opt->{_share} eq 'ARRAY' && ! defined $opt->{_share}[0] ) {
       delete $opt->{_share};
    }
 
@@ -67,7 +67,7 @@ sub _compile {
    my $param = shift || [];
    my $opt   = $self->_init_compile_opts( shift );
 
-   fatal('tts.base.compiler._compile.param') if ! isaref($param);
+   fatal('tts.base.compiler._compile.param') if ref $param ne 'ARRAY';
 
    my $tmp = $self->_examine( $tmpx );
    return $tmp if $self->[TYPE] eq 'ERROR';
@@ -179,8 +179,8 @@ sub _mini_compiler {
    my $param    = shift || fatal('tts.base.compiler._mini_compiler.noparam');
    my $opt      = shift || {};
 
-   fatal('tts.base.compiler._mini_compiler.opt')   if ! ishref($opt  );
-   fatal('tts.base.compiler._mini_compiler.param') if ! ishref($param);
+   fatal('tts.base.compiler._mini_compiler.opt')   if ref $opt   ne 'HASH';
+   fatal('tts.base.compiler._mini_compiler.param') if ref $param ne 'HASH';
 
    foreach my $var ( keys %{ $param } ) {
       my $str = $param->{$var};
@@ -207,8 +207,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Base::Compiler>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Base::Compiler>
+released on C<5 July 2016>.
 
 Private module.
 
@@ -218,12 +218,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
