@@ -6,7 +6,7 @@ use warnings;
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub _examine {
    my $self   = shift;
@@ -56,7 +56,7 @@ sub _examine_type {
    return EMPTY_STRING ,  $TMP if ! $ref;
    return GLOB         => $TMP if   $ref eq 'GLOB';
 
-   if ( isaref( $TMP ) ) {
+   if ( ref $TMP eq 'ARRAY' ) {
       my $ftype  = shift @{ $TMP } || fatal('tts.base.examine._examine_type.ftype');
       my $fthing = shift @{ $TMP } || fatal('tts.base.examine._examine_type.fthing');
       fatal('tts.base.examine._examine_type.extra') if @{ $TMP };
@@ -80,8 +80,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Base::Examine>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Base::Examine>
+released on C<5 July 2016>.
 
 Private module.
 
@@ -91,12 +91,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
