@@ -18,7 +18,7 @@ use constant TYPE_MAP   => qw(
    \   REFERENCE
 );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub _include_no_monolith {
    # no monolith eh?
@@ -193,7 +193,7 @@ sub _interpolate_share_setup {
          fatal('tts.base.include._interpolate.bogus_share', $type_name, $var);
       }
       $var =~ tr/;//d;
-      if ( $var =~ m{ [^a-zA-Z0-9_\$] }xms ) {
+      if ( $var =~ m{ [^a-zA-Z0-9_\$] }xms ) { ## no critic (ProhibitEnumeratedClasses)
          fatal('tts.base.include._interpolate.bogus_share_notbare', $var);
       }
       push @buf, $var;
@@ -229,8 +229,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Base::Include>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Base::Include>
+released on C<5 July 2016>.
 
 Private module.
 
@@ -240,12 +240,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
