@@ -5,9 +5,9 @@ use warnings;
 
 use Carp qw( croak );
 use Text::Template::Simple::Constants qw(:all);
-use Text::Template::Simple::Util      qw( DEBUG LOG ishref fatal );
+use Text::Template::Simple::Util      qw( DEBUG LOG fatal );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 my $CACHE = {}; # in-memory template cache
 
@@ -67,7 +67,7 @@ sub dumper {
    my $self  = shift;
    my $type  = shift || 'structure';
    my $param = shift || {};
-   fatal('tts.cache.dumper.hash')        if not ishref $param;
+   fatal('tts.cache.dumper.hash')        if ref $param ne 'HASH';
    my %valid = map { ($_, $_) } qw( ids structure );
    fatal('tts.cache.dumper.type', $type) if not $valid{ $type };
    my $method = '_dump_' . $type;
@@ -317,7 +317,7 @@ sub _hit_disk {
    }
    if ( $self->_is_meta_version_old( $meta{VERSION} ) ) {
       my $id = $parent->[FILENAME] || $cache_id;
-      warn "(This messeage will only appear once) $id was compiled with"
+      warn "(This message will only appear once) $id was compiled with"
           .' an old version of ' . PARENT . ". Resetting cache.\n";
       return;
    }
@@ -408,7 +408,7 @@ sub _populate_disk {
    my $cache = File::Spec->catfile( $parent->[CACHE_DIR], $cache_id . CACHE_EXT);
    my $fh    = IO::File->new;
    $fh->open($cache, '>') or fatal('tts.cache.populate.write', $cache, $!);
-   flock $fh, Fcntl::LOCK_EX() if IS_FLOCK;
+   flock $fh, Fcntl::LOCK_EX();
    $parent->io->layer($fh);
    my $warn =  $parent->_mini_compiler(
                   $parent->_internal('disk_cache_comment'),
@@ -420,7 +420,7 @@ sub _populate_disk {
    my $ok = print { $fh } '#META:' . $self->_set_meta(\%meta) . "\n",
                           $warn,
                           $parsed;
-   flock $fh, Fcntl::LOCK_UN() if IS_FLOCK;
+   flock $fh, Fcntl::LOCK_UN();
    close $fh or croak "Unable to close filehandle: $!";
    chmod(CACHE_FMODE, $cache) || fatal('tts.cache.populate.chmod');
 
@@ -461,12 +461,12 @@ Text::Template::Simple::Cache - Cache manager
 
 =head1 SYNOPSIS
 
-TODO
+   TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Cache>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Cache>
+released on C<5 July 2016>.
 
 Cache manager for C<Text::Template::Simple>.
 
@@ -490,23 +490,19 @@ if you are using a disk cache.
    $template->cache->dumper( $type, \%opt );
 
 C<TYPE> can either be C<structure> or C<ids>.
-C<dumper> accepts some arguments as a hashref:
+C<dumper> accepts some arguments as a hash reference:
 
    $template->cache->dumper( $type, \%opt );
 
 =over 4
 
-=item *
-
-varname
+=item C<varname>
 
 Controls the name of the dumped structure.
 
-=item *
+=item no_deparse
 
-no_deparse
-
-If you set this to a true value, deparsing will be disabled
+If you set this to a true value, C<deparsing> will be disabled
 
 =back
 
@@ -518,7 +514,7 @@ for in-memory cache.
 
 Early versions of C<Data::Dumper> don' t have a C<Deparse>
 method, so you may need to upgrade your C<Data::Dumper> or
-disable deparse-ing if you want to use this method.
+disable C<deparsing> if you want to use this method.
 
 =head3 ids
 
@@ -554,11 +550,11 @@ or
 
 =head2 hit
 
-TODO
+   TODO
 
 =head2 populate
 
-TODO
+   TODO
 
 =head1 AUTHOR
 
@@ -566,12 +562,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
