@@ -3,10 +3,18 @@ use strict;
 use warnings;
 use overload q{""} => 'get';
 
-use Text::Template::Simple::Constants qw( MAX_FL RE_INVALID_CID );
-use Text::Template::Simple::Util      qw( LOG DEBUG DIGEST fatal );
+use Text::Template::Simple::Constants qw(
+   MAX_FILENAME_LENGTH
+   RE_INVALID_CID
+);
+use Text::Template::Simple::Util qw(
+   LOG
+   DEBUG
+   DIGEST
+   fatal
+);
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub new {
    my $class = shift;
@@ -48,8 +56,14 @@ sub _custom {
    my $regex = shift || RE_INVALID_CID;
       $data  =~ s{$regex}{_}xmsg; # remove bogus characters
    my $len   = length $data;
+
    # limit file name length
-   $data = substr $data, $len - MAX_FL, MAX_FL if $len > MAX_FL;
+   if ( $len > MAX_FILENAME_LENGTH ) {
+      $data = substr $data,
+                     $len - MAX_FILENAME_LENGTH,
+                     MAX_FILENAME_LENGTH;
+   }
+
    return $data;
 }
 
@@ -69,14 +83,14 @@ Text::Template::Simple::Cache::ID - Cache ID generator
 
 =head1 SYNOPSIS
 
-TODO
+   TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Cache::ID>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Cache::ID>
+released on C<5 July 2016>.
 
-TODO
+   TODO
 
 =head1 METHODS
 
@@ -102,12 +116,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
