@@ -14,15 +14,15 @@ use constant IS_REQUIRE => 7;
 use constant HINTS      => 8;
 use constant BITMASK    => 9;
 
-use Text::Template::Simple::Util      qw( ishref fatal );
+use Text::Template::Simple::Util      qw( fatal );
 use Text::Template::Simple::Constants qw( EMPTY_STRING );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub stack {
    my $self    = shift;
    my $opt     = shift || {};
-   fatal('tts.caller.stack.hash') if ! ishref($opt);
+   fatal('tts.caller.stack.hash') if ref $opt ne 'HASH';
    my $frame   = $opt->{frame} || 0;
    my $type    = $opt->{type}  || EMPTY_STRING;
    my(@callers, $context);
@@ -75,10 +75,7 @@ sub _string {
 
    foreach my $c ( reverse @{$callers} ) {
       $rv .= sprintf qq{%s %s() at %s line %s\n},
-                     $c->{context},
-                     $c->{sub},
-                     $c->{file},
-                     $c->{line};
+                     @{ $c }{ qw/ context sub file line / }
    }
 
    $rv = "<!-- $rv -->" if $is_html;
@@ -221,8 +218,8 @@ Text::Template::Simple::Caller - Caller stack tracer
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Caller>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Caller>
+released on C<5 July 2016>.
 
 Caller stack tracer for Text::Template::Simple. This module is not used
 directly inside templates. You must use the global template function
@@ -232,7 +229,7 @@ instead. See L<Text::Template::Simple::Dummy> for usage from the templates.
 
 =head2 stack
 
-Class method. Accepts parameters as a single hashref:
+Class method. Accepts parameters as a single hash reference:
 
    my $dump = Text::Template::Simple::Caller->stack(\%opts);
 
@@ -272,12 +269,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
