@@ -10,12 +10,12 @@ use warnings;
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
    Text::Template::Simple::Util::fatal('tts.caller.stack.hash')
-      if ! Text::Template::Simple::Util::ishref($opt);
+      if ref $opt ne 'HASH';
    $opt->{frame} = 1;
    return Text::Template::Simple::Caller->stack( $opt );
 }
@@ -30,12 +30,12 @@ Text::Template::Simple::Dummy - Container class
 
 =head1 SYNOPSIS
 
-TODO
+   TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Dummy>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Dummy>
+released on C<5 July 2016>.
 
 All templates are compiled into this class.
 
@@ -47,7 +47,7 @@ that are accessible by all templates.
 =head2 stack
 
 Issues a full stack trace and returns the output as string dump. Accepts
-options as a hashref:
+options as a hash reference:
 
    stack({ opt => $option, frame => $backtrace_level });
 
@@ -63,12 +63,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
