@@ -10,12 +10,11 @@ use Text::Template::Simple::Constants qw(:all);
 use Text::Template::Simple::Util qw(
    binary_mode
    fatal
-   ishref
    DEBUG
    LOG
 );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 sub new {
    my $class = shift;
@@ -62,7 +61,7 @@ sub validate {
 }
 
 sub layer {
-   return if ! NEW_PERL;
+   return if ! UNICODE_PERL;
    my $self   = shift;
    my $fh     = shift || fatal('tts.io.layer.fh');
    my $layer  = $self->[MY_IO_LAYER];
@@ -76,9 +75,9 @@ sub slurp {
    my $self = shift;
    my $file = shift;
    my($fh, $seek);
+
    LOG(IO_SLURP => $file) if DEBUG;
 
-   # perl 5.5.3 compat: we need to check if it's a ref first
    if ( ref $file && fileno $file ) {
       $fh   = $file;
       $seek = 1;
@@ -88,8 +87,8 @@ sub slurp {
       $fh->open($file, 'r') or fatal('tts.io.slurp.open', $file, $!);
    }
 
-   flock $fh,    Fcntl::LOCK_SH()  if IS_FLOCK;
-   seek  $fh, 0, Fcntl::SEEK_SET() if IS_FLOCK && $seek;
+   flock $fh,    Fcntl::LOCK_SH();
+   seek  $fh, 0, Fcntl::SEEK_SET() if $seek;
    $self->layer( $fh ) if ! $seek; # apply the layer only if we opened this
 
    if ( $self->_handle_looks_safe( $fh ) ) {
@@ -99,7 +98,7 @@ sub slurp {
    }
 
    my $tmp = do { local $/; my $rv = <$fh>; $rv };
-   flock $fh, Fcntl::LOCK_UN() if IS_FLOCK;
+   flock $fh, Fcntl::LOCK_UN();
    if ( ! $seek ) {
       # close only if we opened this
       close $fh or die "Unable to close filehandle: $!\n";
@@ -201,14 +200,14 @@ Text::Template::Simple::IO - I/O methods
 
 =head1 SYNOPSIS
 
-TODO
+   TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::IO>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::IO>
+released on C<5 July 2016>.
 
-TODO
+   TODO
 
 =head1 METHODS
 
@@ -216,9 +215,9 @@ TODO
 
 Constructor. Accepts an I/O layer name as the parameter.
 
-=head2 layer FH
+=head2 layer FILE_HANDLE
 
-Sets the I/O layer of the supplied filehandle if there is a layer and perl
+Sets the I/O layer of the supplied file handle if there is a layer and C<perl>
 version is greater or equal to C<5.8>.
 
 =head2 slurp FILE_PATH
@@ -249,12 +248,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
