@@ -2,15 +2,17 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use warnings;
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 use constant CMD_CHAR             => 0;
 use constant CMD_ID               => 1;
-use constant CMD_CB               => 2; # callbacks
+use constant CMD_CALLBACK         => 2;
+
 use constant ID_DS                => 0;
 use constant ID_DE                => 1;
 use constant ID_PRE_CHOMP         => 2;
 use constant ID_POST_CHOMP        => 3;
+
 use constant SUBSTR_OFFSET_FIRST  => 0;
 use constant SUBSTR_OFFSET_SECOND => 1;
 use constant SUBSTR_LENGTH        => 1;
@@ -19,7 +21,7 @@ use Text::Template::Simple::Util      qw( LOG DEBUG fatal );
 use Text::Template::Simple::Constants qw( :all );
 
 my @COMMANDS = ( # default command list
-   # cmd            id
+   # command        id
    [ DIR_CAPTURE  , T_CAPTURE   ],
    [ DIR_DYNAMIC  , T_DYNAMIC,  ],
    [ DIR_STATIC   , T_STATIC,   ],
@@ -45,7 +47,7 @@ sub tokenize {
 
    return $self->_empty_token( $tmp ) if ! $tmp;
 
-   my($ds, $de)   = ($self->[ID_DS], $self->[ID_DE]);
+   my($ds,  $de)  = @{ $self }[ ID_DS, ID_DE ];
    my($qds, $qde) = map { quotemeta $_ } $ds, $de;
 
    my(@tokens, $inside);
@@ -88,7 +90,7 @@ sub tilde {
 
 sub quote {
    my(undef, @args) = @_;
-   return Text::Template::Simple::Util::escape( q{"} => @args )
+   return Text::Template::Simple::Util::escape( q{"} => @args );
 }
 
 sub _empty_token {
@@ -105,14 +107,14 @@ sub _empty_token {
 
 sub _get_command_chars {
    my($self, $str) = @_;
-   my($first_cmd, $second_cmd, $last_cmd);
-   # $first is the left-cmd, $last is the right-cmd. $second is the extra
-   $first_cmd  = substr $str, SUBSTR_OFFSET_FIRST , SUBSTR_LENGTH if $str ne EMPTY_STRING;
-   $second_cmd = substr $str, SUBSTR_OFFSET_SECOND, SUBSTR_LENGTH if $str ne EMPTY_STRING;
-   $last_cmd   = substr $str, length($str) - 1    , SUBSTR_LENGTH if $str ne EMPTY_STRING;
-   return $first_cmd  || EMPTY_STRING,
-          $second_cmd || EMPTY_STRING,
-          $last_cmd   || EMPTY_STRING;
+   return
+      $str ne EMPTY_STRING # left
+         ? substr $str, SUBSTR_OFFSET_FIRST , SUBSTR_LENGTH : EMPTY_STRING,
+      $str ne EMPTY_STRING # extra
+         ? substr $str, SUBSTR_OFFSET_SECOND, SUBSTR_LENGTH : EMPTY_STRING,
+      $str ne EMPTY_STRING # right
+         ? substr $str, length($str) - 1    , SUBSTR_LENGTH : EMPTY_STRING,
+   ;
 }
 
 sub _user_commands {
@@ -125,7 +127,7 @@ sub _token_for_command {
    my($self, $tree, $map_keys, $str, $last_cmd, $second_cmd, $cmd, $inside) = @_;
    my($copen, $cclose, $ctoken) = $self->_chomp_token( $second_cmd, $last_cmd );
    my $len  = length $str;
-   my $cb   = $map_keys ? 'quote' : $cmd->[CMD_CB];
+   my $cb   = $map_keys ? 'quote' : $cmd->[CMD_CALLBACK];
    my $soff = $copen ? 2 : 1;
    my $slen = $len - ($cclose ? $soff+1 : 1);
    my $buf  = substr $str, $soff, $slen;
@@ -144,7 +146,7 @@ sub _token_for_command {
    return [
             $val,
             $id,
-            [CHOMP_NONE, CHOMP_NONE],
+            [ (CHOMP_NONE) x 2 ],
             $needs_chomp ? $ctoken : undef # trigger
           ];
 }
@@ -162,7 +164,7 @@ sub _token_for_code {
    return   [
                substr($str, $soff, $slen),
                $map_keys ? T_MAPKEY : T_CODE,
-               [ CHOMP_NONE, CHOMP_NONE ],
+               [ (CHOMP_NONE) x 2 ],
                $needs_chomp ? $ctoken : undef # trigger
             ];
 }
@@ -213,8 +215,8 @@ sub _chomp_token {
 
    my $cboth  = $copen > 0 && $cclose > 0;
 
-   $c |= COLLAPSE_ALL if( ($c & COLLAPSE_LEFT) && ($c & COLLAPSE_RIGHT) );
-   $c |= CHOMP_ALL    if( ($c & CHOMP_LEFT   ) && ($c & CHOMP_RIGHT   ) );
+   $c |= COLLAPSE_ALL if ( ( $c & COLLAPSE_LEFT ) && ( $c & COLLAPSE_RIGHT ) );
+   $c |= CHOMP_ALL    if ( ( $c & CHOMP_LEFT    ) && ( $c & CHOMP_RIGHT    ) );
 
    return $copen, $cclose, $c || CHOMP_NONE;
 }
@@ -269,16 +271,6 @@ sub _visualize_tid {
    return $rv;
 }
 
-sub _visualize_ws {
-   my $self = shift;
-   my $str  = shift;
-      $str =~ s{\r}{\\r}xmsg;
-      $str =~ s{\n}{\\n}xmsg;
-      $str =~ s{\f}{\\f}xmsg;
-      $str =~ s{\s}{\\s}xmsg;
-   return $str;
-}
-
 sub _debug_tokens {
    my $self   = shift;
    my $tokens = shift;
@@ -287,7 +279,9 @@ sub _debug_tokens {
    foreach my $t ( @{ $tokens } ) {
       $buf .=  $self->_debug_tokens_row(
                   $self->_visualize_tid( $t->[TOKEN_ID]  ),
-                  $self->_visualize_ws(  $t->[TOKEN_STR] ),
+                  Text::Template::Simple::Util::visualize_whitespace(
+                     $t->[TOKEN_STR]
+                  ),
                   map { $_ eq 'undef' ? EMPTY_STRING : $_ }
                   map { $self->_visualize_chomp( $_ )     }
                   $t->[TOKEN_CHOMP][TOKEN_CHOMP_NEXT],
@@ -333,27 +327,26 @@ __END__
 
 =head1 NAME
 
-Text::Template::Simple::Tokenizer - Tokenizer
+Text::Template::Simple::Tokenizer - C<Tokenizer>
 
 =head1 SYNOPSIS
 
    use strict;
-   use constant TYPE => 0;
-   use constant DATA => 1;
-   use Text::Template::Simple::Tokenize;
-   my $t = Text::Template::Simple::Tokenize->new( $start_delim, $end_delim );
-   my $tokens = $t->tokenize( $raw_data );
-   foreach my $token ( @{ $tokens } ) {
-      printf "Token type: %s\n", $token->[TYPE];
-      printf "Token data: %s\n", $token->[DATA];
+   use warnings;
+   use Text::Template::Simple::Constants qw( :token );
+   use Text::Template::Simple::Tokenizer;
+   my $t = Text::Template::Simple::Tokenizer->new( $start_delim, $end_delim );
+   foreach my $token ( @{ $t->tokenize( $raw_data ) } ) {
+      printf "Token type: %s\n", $token->[TOKEN_ID];
+      printf "Token data: %s\n", $token->[TOKEN_STR];
    }
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Tokenizer>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Tokenizer>
+released on C<5 July 2016>.
 
-Tokenizes the input with the defined delimiter pair.
+Splits the input into tokens with the defined delimiter pair.
 
 =head1 METHODS
 
@@ -362,9 +355,9 @@ Tokenizes the input with the defined delimiter pair.
 The object constructor. Accepts two parameters in this order:
 C<start_delimiter> and C<end_delimiter>.
 
-=head2 tokenize
+=head2 C<tokenize>
 
-Tokenizes the input with the supplied delimiter pair. Accepts a single
+Splits the input into tokens with the supplied delimiter pair. Accepts a single
 parameter: the raw template string.
 
 =head2 ESCAPE METHODS
@@ -383,12 +376,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
