@@ -9,11 +9,10 @@ use Text::Template::Simple::Constants qw(
    EMPTY_STRING
 );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 BEGIN {
-   # create a wrapper for binmode() 
-   if ( NEW_PERL ) {
+   if ( UNICODE_PERL ) {
       # older perl binmode() does not accept a second param
       *binary_mode = sub {
          my($fh, $layer) = @_;
@@ -24,9 +23,9 @@ BEGIN {
       *binary_mode = sub { binmode $_[0] };
    }
    our %EXPORT_TAGS = (
-      macro => [qw( isaref      ishref iscref                  )],
       util  => [qw( binary_mode DIGEST trim rtrim ltrim escape )],
       debug => [qw( fatal       DEBUG  LOG  L                  )],
+      misc  => [qw( visualize_whitespace                       )],
    );
    our @EXPORT_OK    = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
    $EXPORT_TAGS{all} = \@EXPORT_OK;
@@ -110,13 +109,11 @@ my $lang = {
    }
 };
 
+my @WHITESPACE_SYMBOLS = map { q{\\} . $_ } qw( r n f s );
+
 my $DEBUG = 0; # Disabled by default
 my $DIGEST;    # Will hold digester class name.
 
-sub isaref { my $x = shift; return ref($x) eq 'ARRAY' };
-sub ishref { my $x = shift; return ref($x) eq 'HASH'  };
-sub iscref { my $x = shift; return ref($x) eq 'CODE'  };
-
 sub L {
    my($type, $id, @param) = @_;
    croak q{Type parameter to L() is missing} if ! $type;
@@ -165,6 +162,25 @@ sub rtrim {
    return $s;
 }
 
+sub visualize_whitespace {
+   my($str) = @_;
+   $str =~ s<[$_]><$_>xmsg for @WHITESPACE_SYMBOLS;
+   return $str;
+}
+
+*LOG = __PACKAGE__->can('MYLOG') || sub {
+   my @args = @_;
+   my $self    = ref $args[0] ? shift @args : undef;
+   my $id      = shift @args;
+   my $message = shift @args;
+      $id      = 'DEBUG'        if not defined $id;
+      $message = '<NO MESSAGE>' if not defined $message;
+      $id      =~ s{_}{ }xmsg;
+   $message = sprintf q{[ % 15s ] %s}, $id, $message;
+   warn "$message\n";
+   return;
+};
+
 sub DEBUG {
    my $thing = shift;
 
@@ -202,20 +218,6 @@ sub DIGEST {
    return $DIGEST->new;
 }
 
-sub LOG {
-   my @args = @_;
-   return MYLOG( @args ) if defined &MYLOG;
-   my $self    = ref $args[0] ? shift @args : undef;
-   my $id      = shift @args;
-   my $message = shift @args;
-      $id      = 'DEBUG'        if not defined $id;
-      $message = '<NO MESSAGE>' if not defined $message;
-      $id      =~ s{_}{ }xmsg;
-   $message = sprintf q{[ % 15s ] %s}, $id, $message;
-   warn "$message\n";
-   return;
-}
-
 sub _is_parent_object {
    my $test = shift;
    return ! defined $test       ? 0
@@ -236,12 +238,12 @@ Text::Template::Simple::Util - Utility functions
 
 =head1 SYNOPSIS
 
-TODO
+   TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.86> of C<Text::Template::Simple::Util>
-released on C<5 March 2012>.
+This document describes version C<0.90> of C<Text::Template::Simple::Util>
+released on C<5 July 2016>.
 
 Contains utility functions for Text::Template::Simple.
 
@@ -253,49 +255,42 @@ Returns the debug status.
 
 =head2 DIGEST
 
-Returns the digester object.
+Returns the C<digester> object.
 
-=head2 binary_mode FH, LAYER
+=head2 binary_mode FILE_HANDLE, LAYER
 
-Sets the I/O layer of FH in modern perls, only sets binmode on FH otherwise.
+Sets the I/O layer of C<FILE_HANDLE> in modern C<perls>, only sets C<binmode>
+on C<FILE_HANDLE> otherwise.
 
-=head2 L TYPE, ID [, PARAMS]
+=head2 L TYPE, ID [, PARAMETERS]
 
 Internal method.
 
-=head2 fatal ID [, PARAMS]
+=head2 fatal ID [, PARAMETERS]
 
 Internal method.
 
-=head2 isaref THING
-
-Returns true if C<THING> is an ARRAY.
-
-=head2 ishref THING
-
-Returns true if C<THING> is a HASH.
-
-=head2 iscref THING
-
-Returns true if C<THING> is a CODE.
-
-=head2 trim STRING
+=head2 C<trim STRING>
 
 Returns the trimmed version of the C<STRING>.
 
-=head2 ltrim STRING
+=head2 C<ltrim STRING>
 
 Returns the left trimmed version of the C<STRING>.
 
-=head2 rtrim STRING
+=head2 C<rtrim STRING>
 
 Returns the right trimmed version of the C<STRING>.
 
 =head2 escape CHAR, STRING
 
-Escapes all occurrances of C<CHAR> in C<STRING> with backslashes.
+Escapes all occurrences of C<CHAR> in C<STRING> with backslashes.
 
-=head1 OVERRIDABLE FUNCTIONS
+=head2 visualize_whitespace STRING
+
+Replaces the white space in C<STRING> with visual representations.
+
+=head1 C<OVERRIDABLE FUNCTIONS>
 
 =head2 LOG
 
@@ -314,12 +309,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.24.0 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
